.rss_item_desc { 
	display: none; 
}

.rss_feed_title {
	font-size: larger;
	text-align: center;
}

.rss_item_list { 
	list-style-type: none;
	font-family: sans-serif;
	font-size: smaller;
	margin: 1em 0;
	padding: 0;
	border-top: 1px #000 solid;
}

.rss_item_list a {
	display: block;
	background-color: #fff;
	border-bottom: 1px #000 solid;
	text-align: center;
	text-decoration: none;
	color: #000;
}

.rss_item_list a:hover {
	background-color: yellow;
	color: black;
}

.rss_item_list a:visited {
	color: #000;
}
